# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class SamlIndexedEndpoint(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'binding': 'str',
        'index': 'int',
        'is_default': 'bool',
        'location': 'str',
        'response_location': 'str'
    }

    attribute_map = {
        'binding': 'Binding',
        'index': 'Index',
        'is_default': 'IsDefault',
        'location': 'Location',
        'response_location': 'ResponseLocation'
    }

    def __init__(self, binding=None, index=None, is_default=None, location=None, response_location=None, local_vars_configuration=None):  # noqa: E501
        """SamlIndexedEndpoint - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._binding = None
        self._index = None
        self._is_default = None
        self._location = None
        self._response_location = None
        self.discriminator = None

        if binding is not None:
            self.binding = binding
        if index is not None:
            self.index = index
        self.is_default = is_default
        if location is not None:
            self.location = location
        self.response_location = response_location

    @property
    def binding(self):
        """Gets the binding of this SamlIndexedEndpoint.  # noqa: E501


        :return: The binding of this SamlIndexedEndpoint.  # noqa: E501
        :rtype: str
        """
        return self._binding

    @binding.setter
    def binding(self, binding):
        """Sets the binding of this SamlIndexedEndpoint.


        :param binding: The binding of this SamlIndexedEndpoint.  # noqa: E501
        :type binding: str
        """

        self._binding = binding

    @property
    def index(self):
        """Gets the index of this SamlIndexedEndpoint.  # noqa: E501


        :return: The index of this SamlIndexedEndpoint.  # noqa: E501
        :rtype: int
        """
        return self._index

    @index.setter
    def index(self, index):
        """Sets the index of this SamlIndexedEndpoint.


        :param index: The index of this SamlIndexedEndpoint.  # noqa: E501
        :type index: int
        """

        self._index = index

    @property
    def is_default(self):
        """Gets the is_default of this SamlIndexedEndpoint.  # noqa: E501


        :return: The is_default of this SamlIndexedEndpoint.  # noqa: E501
        :rtype: bool
        """
        return self._is_default

    @is_default.setter
    def is_default(self, is_default):
        """Sets the is_default of this SamlIndexedEndpoint.


        :param is_default: The is_default of this SamlIndexedEndpoint.  # noqa: E501
        :type is_default: bool
        """

        self._is_default = is_default

    @property
    def location(self):
        """Gets the location of this SamlIndexedEndpoint.  # noqa: E501


        :return: The location of this SamlIndexedEndpoint.  # noqa: E501
        :rtype: str
        """
        return self._location

    @location.setter
    def location(self, location):
        """Sets the location of this SamlIndexedEndpoint.


        :param location: The location of this SamlIndexedEndpoint.  # noqa: E501
        :type location: str
        """

        self._location = location

    @property
    def response_location(self):
        """Gets the response_location of this SamlIndexedEndpoint.  # noqa: E501


        :return: The response_location of this SamlIndexedEndpoint.  # noqa: E501
        :rtype: str
        """
        return self._response_location

    @response_location.setter
    def response_location(self, response_location):
        """Sets the response_location of this SamlIndexedEndpoint.


        :param response_location: The response_location of this SamlIndexedEndpoint.  # noqa: E501
        :type response_location: str
        """

        self._response_location = response_location

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, SamlIndexedEndpoint):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, SamlIndexedEndpoint):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class OrmPricingPlan(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        '_class': 'str',
        'edges': 'OrmPricingPlanEdges',
        'id': 'int',
        'name': 'str',
        'stripe_price_id': 'str',
        'stripe_product_id': 'str',
        'type': 'str'
    }

    attribute_map = {
        '_class': 'class',
        'edges': 'edges',
        'id': 'id',
        'name': 'name',
        'stripe_price_id': 'stripe_price_id',
        'stripe_product_id': 'stripe_product_id',
        'type': 'type'
    }

    def __init__(self, _class=None, edges=None, id=None, name=None, stripe_price_id=None, stripe_product_id=None, type=None, local_vars_configuration=None):  # noqa: E501
        """OrmPricingPlan - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self.__class = None
        self._edges = None
        self._id = None
        self._name = None
        self._stripe_price_id = None
        self._stripe_product_id = None
        self._type = None
        self.discriminator = None

        if _class is not None:
            self._class = _class
        if edges is not None:
            self.edges = edges
        if id is not None:
            self.id = id
        if name is not None:
            self.name = name
        self.stripe_price_id = stripe_price_id
        self.stripe_product_id = stripe_product_id
        if type is not None:
            self.type = type

    @property
    def _class(self):
        """Gets the _class of this OrmPricingPlan.  # noqa: E501


        :return: The _class of this OrmPricingPlan.  # noqa: E501
        :rtype: str
        """
        return self.__class

    @_class.setter
    def _class(self, _class):
        """Sets the _class of this OrmPricingPlan.


        :param _class: The _class of this OrmPricingPlan.  # noqa: E501
        :type _class: str
        """

        self.__class = _class

    @property
    def edges(self):
        """Gets the edges of this OrmPricingPlan.  # noqa: E501


        :return: The edges of this OrmPricingPlan.  # noqa: E501
        :rtype: OrmPricingPlanEdges
        """
        return self._edges

    @edges.setter
    def edges(self, edges):
        """Sets the edges of this OrmPricingPlan.


        :param edges: The edges of this OrmPricingPlan.  # noqa: E501
        :type edges: OrmPricingPlanEdges
        """

        self._edges = edges

    @property
    def id(self):
        """Gets the id of this OrmPricingPlan.  # noqa: E501


        :return: The id of this OrmPricingPlan.  # noqa: E501
        :rtype: int
        """
        return self._id

    @id.setter
    def id(self, id):
        """Sets the id of this OrmPricingPlan.


        :param id: The id of this OrmPricingPlan.  # noqa: E501
        :type id: int
        """

        self._id = id

    @property
    def name(self):
        """Gets the name of this OrmPricingPlan.  # noqa: E501


        :return: The name of this OrmPricingPlan.  # noqa: E501
        :rtype: str
        """
        return self._name

    @name.setter
    def name(self, name):
        """Sets the name of this OrmPricingPlan.


        :param name: The name of this OrmPricingPlan.  # noqa: E501
        :type name: str
        """

        self._name = name

    @property
    def stripe_price_id(self):
        """Gets the stripe_price_id of this OrmPricingPlan.  # noqa: E501


        :return: The stripe_price_id of this OrmPricingPlan.  # noqa: E501
        :rtype: str
        """
        return self._stripe_price_id

    @stripe_price_id.setter
    def stripe_price_id(self, stripe_price_id):
        """Sets the stripe_price_id of this OrmPricingPlan.


        :param stripe_price_id: The stripe_price_id of this OrmPricingPlan.  # noqa: E501
        :type stripe_price_id: str
        """

        self._stripe_price_id = stripe_price_id

    @property
    def stripe_product_id(self):
        """Gets the stripe_product_id of this OrmPricingPlan.  # noqa: E501


        :return: The stripe_product_id of this OrmPricingPlan.  # noqa: E501
        :rtype: str
        """
        return self._stripe_product_id

    @stripe_product_id.setter
    def stripe_product_id(self, stripe_product_id):
        """Sets the stripe_product_id of this OrmPricingPlan.


        :param stripe_product_id: The stripe_product_id of this OrmPricingPlan.  # noqa: E501
        :type stripe_product_id: str
        """

        self._stripe_product_id = stripe_product_id

    @property
    def type(self):
        """Gets the type of this OrmPricingPlan.  # noqa: E501


        :return: The type of this OrmPricingPlan.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this OrmPricingPlan.


        :param type: The type of this OrmPricingPlan.  # noqa: E501
        :type type: str
        """

        self._type = type

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, OrmPricingPlan):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, OrmPricingPlan):
            return True

        return self.to_dict() != other.to_dict()



import sys
from typing import Any, Callable, List, Optional

import click
import sentry_sdk
import requests

import vessl
from vessl.util.echo import print_info, style_prompt
from vessl.util import logger
from vessl.util.constant import (
    VESSL_LOG_LEVEL,
    DATADOG_CLIENT_TOKEN,
    DATADOG_HOST,
    VESSL_ENV,
    VESSL_DATA_COLLECTION_OPT_OUT
)
from vessl._version import __VERSION__
from vessl.util.exception import (
    DEFAULT_ERROR_MESSAGE,
    InvalidTokenError,
    VesslException,
)
from vessl.util.config import (
    notified_user_data_collection,
    create_user_data_collection_file,
)

def no_interaction_callback(ctx: click.Context, param: click.Parameter, value: bool):
    ctx.obj["no_interaction"] = value


no_interaction_option = click.Option(
    ["--no-interaction"],
    is_flag=True,
    is_eager=True,
    expose_value=False,
    hidden=True,
    callback=no_interaction_callback,
)


class VesslArgument(click.Argument):
    """Custom argument class"""

    def __init__(self, *args, **kwargs) -> None:
        self.prompter = kwargs.pop("prompter", None)
        super().__init__(*args, **kwargs)

    def process_value(self, ctx: click.Context, value: Any) -> Any:
        """Override parent method to invoke prompter before processing value."""
        if (
            (value is None or (self.multiple == True and not value))
            and self.prompter is not None
            and not ctx.obj["no_interaction"]
        ):
            value = self.prompter(ctx, self, value)

        return super().process_value(ctx, value)


class VesslOption(click.Option):
    """Custom option class"""

    def __init__(self, *args, **kwargs) -> None:
        self.prompter = kwargs.pop("prompter", None)
        super().__init__(*args, **kwargs)

    def process_value(self, ctx: click.Context, value: Any) -> Any:
        """Override parent method to invoke prompter before processing value."""
        if (
            (value is None or (self.multiple == True and not value))
            and self.prompter is not None
            and not ctx.obj["no_interaction"]
        ):
            value = self.prompter(ctx, self, value)

        return super().process_value(ctx, value)


class VesslContionalOption(click.Option):
    """Custom option class where the requirement is determined by the values of another option.
    Currently, multiple conditions are not supported.
    """

    def __init__(self, *args, **kwargs) -> None:
        self.prompter = kwargs.pop("prompter", None)
        self.condition = kwargs.pop("condition", None)

        super().__init__(*args, **kwargs)

    def match_condition(self, ctx: click.Context) -> bool:
        if self.condition is None:
            return True

        param_name, values = self.condition
        # if `values` has multiple values, check if the list contains param value.
        if isinstance(values, list) or isinstance(values, tuple):
            return ctx.params.get(param_name) in values
        # if `values` is a single value, check if it is equal to param value
        return ctx.params.get(param_name) == values

    def prompt_for_value(self, ctx):
        if self.match_condition(ctx):
            return super().prompt_for_value(ctx)

    def process_value(self, ctx: click.Context, value: Any) -> Any:
        """Override parent method to invoke prompter before processing value."""

        if (
            (value is None or (self.multiple and not value))
            and self.prompter is not None
            and not ctx.obj["no_interaction"]
            and self.match_condition(ctx)
        ):
            value = self.prompter(ctx, self, value)

        return super().process_value(ctx, value)


class VesslCommand(click.Command):
    def __init__(
        self,
        login_required: bool = False,
        params: Optional[List[click.Parameter]] = None,
        **kwargs,
    ) -> None:
        self.login_required = login_required

        params = params or []
        params = [no_interaction_option] + params

        super().__init__(params=params, **kwargs)

    def make_context(self, *args, **kwargs) -> click.Context:
        if self.login_required:
            vessl.vessl_api.set_access_token(no_prompt=True)

        return super().make_context(*args, **kwargs)
    
    def invoke(self, ctx):
        command_path = []
        originalctx = ctx
        while ctx:
            command_path.append(ctx.command.name)
            ctx = ctx.parent
        command_path.reverse()
        cmd = " ".join(command_path)
        dd_log_cmd(command_name=cmd)

        return super().invoke(ctx=originalctx)


class VesslGroup(click.Group):
    command_class = VesslCommand
    group_class = type  # Use VesslGroup recursively for sub-groups

    def vessl_command(self, login_required: bool = True, *args, **kwargs):
        kwargs["login_required"] = login_required
        return super().command(*args, **kwargs)

    def vessl_run_command(self, login_required: bool = False, *args, **kwargs):
        kwargs["login_required"] = login_required
        return super().command(*args, **kwargs)

    def main(self, *args, **kwargs):
        try:
            return super().main(*args, **kwargs)

        except InvalidTokenError as e:
            exc_info = e if VESSL_LOG_LEVEL == "DEBUG" else False
            logger.fatal("Invalid access token. Please run `vessl configure`.", exc_info=exc_info)
            sys.exit(1)

        except VesslException as e:
            exc_info = e
            logger.exception(f"{e.__class__.__name__}: {str(e)}", exc_info=exc_info)
            sys.exit(e.exit_code)

        except Exception as e:
            sentry_sdk.capture_exception(e)
            sentry_sdk.flush()

            exc_info = e
            logger.fatal(DEFAULT_ERROR_MESSAGE, exc_info=exc_info)
            sys.exit(1)


def vessl_argument(*param_decls: str, **attrs: Any) -> Callable:
    attrs["cls"] = VesslArgument
    return click.argument(*param_decls, **attrs)


def vessl_option(*param_decls: str, **attrs: Any) -> Callable:
    attrs["cls"] = VesslOption

    # Style prompt
    if ("prompt" in attrs) and (attrs["prompt"] is not None):
        attrs["prompt"] = style_prompt(attrs.pop("prompt", None))
    return click.option(*param_decls, **attrs)


def vessl_conditional_option(*param_decls: str, **attrs: Any) -> Callable:
    attrs["cls"] = VesslContionalOption

    # Style prompt
    if ("prompt" in attrs) and (attrs["prompt"] is not None):
        attrs["prompt"] = style_prompt(attrs.pop("prompt", None))
    return click.option(*param_decls, **attrs)

def dd_log_cmd(command_name):
    if not notified_user_data_collection():
        print_info("Basic information on command executions will be collected to improve future CLI version releases.")
        print_info("More information can be found in ~/.vessl/tracing-agreement file.")
        print()
        create_user_data_collection_file()
    
    if not VESSL_DATA_COLLECTION_OPT_OUT:
        headers = {
                "DD-API-KEY": DATADOG_CLIENT_TOKEN,
                "Content-Type": "application/json"
        }
        event = {
                "ddsource": "python",
                "ddtags": f"command:{command_name},env:{VESSL_ENV},version:{__VERSION__}",
                "hostname": sys.version,
                "service": "vessl-cli",
        }
        requests.post(DATADOG_HOST, headers=headers, json=[event])




# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class LlmLLMWorkflowCreateResponse(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'cluster': 'ProtoCluster',
        'initial_revision': 'ProtoLLMWorkflowRevision',
        'model_service': 'ProtoModelService',
        'resource_preset': 'ProtoResourcePreset',
        'workflow': 'ProtoLLMWorkflow'
    }

    attribute_map = {
        'cluster': 'Cluster',
        'initial_revision': 'InitialRevision',
        'model_service': 'ModelService',
        'resource_preset': 'ResourcePreset',
        'workflow': 'Workflow'
    }

    def __init__(self, cluster=None, initial_revision=None, model_service=None, resource_preset=None, workflow=None, local_vars_configuration=None):  # noqa: E501
        """LlmLLMWorkflowCreateResponse - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._cluster = None
        self._initial_revision = None
        self._model_service = None
        self._resource_preset = None
        self._workflow = None
        self.discriminator = None

        if cluster is not None:
            self.cluster = cluster
        if initial_revision is not None:
            self.initial_revision = initial_revision
        if model_service is not None:
            self.model_service = model_service
        if resource_preset is not None:
            self.resource_preset = resource_preset
        if workflow is not None:
            self.workflow = workflow

    @property
    def cluster(self):
        """Gets the cluster of this LlmLLMWorkflowCreateResponse.  # noqa: E501


        :return: The cluster of this LlmLLMWorkflowCreateResponse.  # noqa: E501
        :rtype: ProtoCluster
        """
        return self._cluster

    @cluster.setter
    def cluster(self, cluster):
        """Sets the cluster of this LlmLLMWorkflowCreateResponse.


        :param cluster: The cluster of this LlmLLMWorkflowCreateResponse.  # noqa: E501
        :type cluster: ProtoCluster
        """

        self._cluster = cluster

    @property
    def initial_revision(self):
        """Gets the initial_revision of this LlmLLMWorkflowCreateResponse.  # noqa: E501


        :return: The initial_revision of this LlmLLMWorkflowCreateResponse.  # noqa: E501
        :rtype: ProtoLLMWorkflowRevision
        """
        return self._initial_revision

    @initial_revision.setter
    def initial_revision(self, initial_revision):
        """Sets the initial_revision of this LlmLLMWorkflowCreateResponse.


        :param initial_revision: The initial_revision of this LlmLLMWorkflowCreateResponse.  # noqa: E501
        :type initial_revision: ProtoLLMWorkflowRevision
        """

        self._initial_revision = initial_revision

    @property
    def model_service(self):
        """Gets the model_service of this LlmLLMWorkflowCreateResponse.  # noqa: E501


        :return: The model_service of this LlmLLMWorkflowCreateResponse.  # noqa: E501
        :rtype: ProtoModelService
        """
        return self._model_service

    @model_service.setter
    def model_service(self, model_service):
        """Sets the model_service of this LlmLLMWorkflowCreateResponse.


        :param model_service: The model_service of this LlmLLMWorkflowCreateResponse.  # noqa: E501
        :type model_service: ProtoModelService
        """

        self._model_service = model_service

    @property
    def resource_preset(self):
        """Gets the resource_preset of this LlmLLMWorkflowCreateResponse.  # noqa: E501


        :return: The resource_preset of this LlmLLMWorkflowCreateResponse.  # noqa: E501
        :rtype: ProtoResourcePreset
        """
        return self._resource_preset

    @resource_preset.setter
    def resource_preset(self, resource_preset):
        """Sets the resource_preset of this LlmLLMWorkflowCreateResponse.


        :param resource_preset: The resource_preset of this LlmLLMWorkflowCreateResponse.  # noqa: E501
        :type resource_preset: ProtoResourcePreset
        """

        self._resource_preset = resource_preset

    @property
    def workflow(self):
        """Gets the workflow of this LlmLLMWorkflowCreateResponse.  # noqa: E501


        :return: The workflow of this LlmLLMWorkflowCreateResponse.  # noqa: E501
        :rtype: ProtoLLMWorkflow
        """
        return self._workflow

    @workflow.setter
    def workflow(self, workflow):
        """Sets the workflow of this LlmLLMWorkflowCreateResponse.


        :param workflow: The workflow of this LlmLLMWorkflowCreateResponse.  # noqa: E501
        :type workflow: ProtoLLMWorkflow
        """

        self._workflow = workflow

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LlmLLMWorkflowCreateResponse):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LlmLLMWorkflowCreateResponse):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class V1S3StorageConfiguration(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'bucket': 'str',
        'credential': 'V1S3Credential',
        'endpoint_url': 'str',
        'prefix': 'str'
    }

    attribute_map = {
        'bucket': 'bucket',
        'credential': 'credential',
        'endpoint_url': 'endpoint_url',
        'prefix': 'prefix'
    }

    def __init__(self, bucket=None, credential=None, endpoint_url=None, prefix='/', local_vars_configuration=None):  # noqa: E501
        """V1S3StorageConfiguration - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._bucket = None
        self._credential = None
        self._endpoint_url = None
        self._prefix = None
        self.discriminator = None

        self.bucket = bucket
        self.credential = credential
        self.endpoint_url = endpoint_url
        if prefix is not None:
            self.prefix = prefix

    @property
    def bucket(self):
        """Gets the bucket of this V1S3StorageConfiguration.  # noqa: E501


        :return: The bucket of this V1S3StorageConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._bucket

    @bucket.setter
    def bucket(self, bucket):
        """Sets the bucket of this V1S3StorageConfiguration.


        :param bucket: The bucket of this V1S3StorageConfiguration.  # noqa: E501
        :type bucket: str
        """
        if self.local_vars_configuration.client_side_validation and bucket is None:  # noqa: E501
            raise ValueError("Invalid value for `bucket`, must not be `None`")  # noqa: E501

        self._bucket = bucket

    @property
    def credential(self):
        """Gets the credential of this V1S3StorageConfiguration.  # noqa: E501


        :return: The credential of this V1S3StorageConfiguration.  # noqa: E501
        :rtype: V1S3Credential
        """
        return self._credential

    @credential.setter
    def credential(self, credential):
        """Sets the credential of this V1S3StorageConfiguration.


        :param credential: The credential of this V1S3StorageConfiguration.  # noqa: E501
        :type credential: V1S3Credential
        """
        if self.local_vars_configuration.client_side_validation and credential is None:  # noqa: E501
            raise ValueError("Invalid value for `credential`, must not be `None`")  # noqa: E501

        self._credential = credential

    @property
    def endpoint_url(self):
        """Gets the endpoint_url of this V1S3StorageConfiguration.  # noqa: E501


        :return: The endpoint_url of this V1S3StorageConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._endpoint_url

    @endpoint_url.setter
    def endpoint_url(self, endpoint_url):
        """Sets the endpoint_url of this V1S3StorageConfiguration.


        :param endpoint_url: The endpoint_url of this V1S3StorageConfiguration.  # noqa: E501
        :type endpoint_url: str
        """

        self._endpoint_url = endpoint_url

    @property
    def prefix(self):
        """Gets the prefix of this V1S3StorageConfiguration.  # noqa: E501


        :return: The prefix of this V1S3StorageConfiguration.  # noqa: E501
        :rtype: str
        """
        return self._prefix

    @prefix.setter
    def prefix(self, prefix):
        """Sets the prefix of this V1S3StorageConfiguration.


        :param prefix: The prefix of this V1S3StorageConfiguration.  # noqa: E501
        :type prefix: str
        """

        self._prefix = prefix

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, V1S3StorageConfiguration):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, V1S3StorageConfiguration):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class ResponseVolumeV2FederateInfo(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'bucket_name': 'str',
        'endpoint': 'str',
        'force_path_style': 'bool',
        'gcs_token': 'StorageGoogleStorageFederationToken',
        'path': 'str',
        'region': 'str',
        's3_token': 'StorageS3FederationToken',
        'type': 'str'
    }

    attribute_map = {
        'bucket_name': 'bucket_name',
        'endpoint': 'endpoint',
        'force_path_style': 'force_path_style',
        'gcs_token': 'gcs_token',
        'path': 'path',
        'region': 'region',
        's3_token': 's3_token',
        'type': 'type'
    }

    def __init__(self, bucket_name=None, endpoint=None, force_path_style=None, gcs_token=None, path=None, region=None, s3_token=None, type=None, local_vars_configuration=None):  # noqa: E501
        """ResponseVolumeV2FederateInfo - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._bucket_name = None
        self._endpoint = None
        self._force_path_style = None
        self._gcs_token = None
        self._path = None
        self._region = None
        self._s3_token = None
        self._type = None
        self.discriminator = None

        if bucket_name is not None:
            self.bucket_name = bucket_name
        self.endpoint = endpoint
        self.force_path_style = force_path_style
        if gcs_token is not None:
            self.gcs_token = gcs_token
        if path is not None:
            self.path = path
        self.region = region
        if s3_token is not None:
            self.s3_token = s3_token
        self.type = type

    @property
    def bucket_name(self):
        """Gets the bucket_name of this ResponseVolumeV2FederateInfo.  # noqa: E501


        :return: The bucket_name of this ResponseVolumeV2FederateInfo.  # noqa: E501
        :rtype: str
        """
        return self._bucket_name

    @bucket_name.setter
    def bucket_name(self, bucket_name):
        """Sets the bucket_name of this ResponseVolumeV2FederateInfo.


        :param bucket_name: The bucket_name of this ResponseVolumeV2FederateInfo.  # noqa: E501
        :type bucket_name: str
        """

        self._bucket_name = bucket_name

    @property
    def endpoint(self):
        """Gets the endpoint of this ResponseVolumeV2FederateInfo.  # noqa: E501


        :return: The endpoint of this ResponseVolumeV2FederateInfo.  # noqa: E501
        :rtype: str
        """
        return self._endpoint

    @endpoint.setter
    def endpoint(self, endpoint):
        """Sets the endpoint of this ResponseVolumeV2FederateInfo.


        :param endpoint: The endpoint of this ResponseVolumeV2FederateInfo.  # noqa: E501
        :type endpoint: str
        """

        self._endpoint = endpoint

    @property
    def force_path_style(self):
        """Gets the force_path_style of this ResponseVolumeV2FederateInfo.  # noqa: E501


        :return: The force_path_style of this ResponseVolumeV2FederateInfo.  # noqa: E501
        :rtype: bool
        """
        return self._force_path_style

    @force_path_style.setter
    def force_path_style(self, force_path_style):
        """Sets the force_path_style of this ResponseVolumeV2FederateInfo.


        :param force_path_style: The force_path_style of this ResponseVolumeV2FederateInfo.  # noqa: E501
        :type force_path_style: bool
        """
        if self.local_vars_configuration.client_side_validation and force_path_style is None:  # noqa: E501
            raise ValueError("Invalid value for `force_path_style`, must not be `None`")  # noqa: E501

        self._force_path_style = force_path_style

    @property
    def gcs_token(self):
        """Gets the gcs_token of this ResponseVolumeV2FederateInfo.  # noqa: E501


        :return: The gcs_token of this ResponseVolumeV2FederateInfo.  # noqa: E501
        :rtype: StorageGoogleStorageFederationToken
        """
        return self._gcs_token

    @gcs_token.setter
    def gcs_token(self, gcs_token):
        """Sets the gcs_token of this ResponseVolumeV2FederateInfo.


        :param gcs_token: The gcs_token of this ResponseVolumeV2FederateInfo.  # noqa: E501
        :type gcs_token: StorageGoogleStorageFederationToken
        """

        self._gcs_token = gcs_token

    @property
    def path(self):
        """Gets the path of this ResponseVolumeV2FederateInfo.  # noqa: E501


        :return: The path of this ResponseVolumeV2FederateInfo.  # noqa: E501
        :rtype: str
        """
        return self._path

    @path.setter
    def path(self, path):
        """Sets the path of this ResponseVolumeV2FederateInfo.


        :param path: The path of this ResponseVolumeV2FederateInfo.  # noqa: E501
        :type path: str
        """

        self._path = path

    @property
    def region(self):
        """Gets the region of this ResponseVolumeV2FederateInfo.  # noqa: E501


        :return: The region of this ResponseVolumeV2FederateInfo.  # noqa: E501
        :rtype: str
        """
        return self._region

    @region.setter
    def region(self, region):
        """Sets the region of this ResponseVolumeV2FederateInfo.


        :param region: The region of this ResponseVolumeV2FederateInfo.  # noqa: E501
        :type region: str
        """

        self._region = region

    @property
    def s3_token(self):
        """Gets the s3_token of this ResponseVolumeV2FederateInfo.  # noqa: E501


        :return: The s3_token of this ResponseVolumeV2FederateInfo.  # noqa: E501
        :rtype: StorageS3FederationToken
        """
        return self._s3_token

    @s3_token.setter
    def s3_token(self, s3_token):
        """Sets the s3_token of this ResponseVolumeV2FederateInfo.


        :param s3_token: The s3_token of this ResponseVolumeV2FederateInfo.  # noqa: E501
        :type s3_token: StorageS3FederationToken
        """

        self._s3_token = s3_token

    @property
    def type(self):
        """Gets the type of this ResponseVolumeV2FederateInfo.  # noqa: E501


        :return: The type of this ResponseVolumeV2FederateInfo.  # noqa: E501
        :rtype: str
        """
        return self._type

    @type.setter
    def type(self, type):
        """Sets the type of this ResponseVolumeV2FederateInfo.


        :param type: The type of this ResponseVolumeV2FederateInfo.  # noqa: E501
        :type type: str
        """
        if self.local_vars_configuration.client_side_validation and type is None:  # noqa: E501
            raise ValueError("Invalid value for `type`, must not be `None`")  # noqa: E501

        self._type = type

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseVolumeV2FederateInfo):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ResponseVolumeV2FederateInfo):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class ResponseVolumeSourceEntity(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'artifact': 'ResponseArtifact',
        'cifs': 'V1CIFSMount',
        'csi': 'V1CSIMount',
        'dataset': 'ResponseDatasetInfo',
        'entity_not_found': 'bool',
        'git': 'V1GitReference',
        'googledisk': 'V1GoogleDiskMount',
        'gs': 'V1GSReference',
        'hostpath': 'V1HostPathMount',
        'model': 'ResponseModelCandidateInfo',
        'nfs': 'V1NFSMount',
        's3': 'V1S3Reference',
        'source_entity_type': 'str'
    }

    attribute_map = {
        'artifact': 'artifact',
        'cifs': 'cifs',
        'csi': 'csi',
        'dataset': 'dataset',
        'entity_not_found': 'entity_not_found',
        'git': 'git',
        'googledisk': 'googledisk',
        'gs': 'gs',
        'hostpath': 'hostpath',
        'model': 'model',
        'nfs': 'nfs',
        's3': 's3',
        'source_entity_type': 'source_entity_type'
    }

    def __init__(self, artifact=None, cifs=None, csi=None, dataset=None, entity_not_found=None, git=None, googledisk=None, gs=None, hostpath=None, model=None, nfs=None, s3=None, source_entity_type=None, local_vars_configuration=None):  # noqa: E501
        """ResponseVolumeSourceEntity - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._artifact = None
        self._cifs = None
        self._csi = None
        self._dataset = None
        self._entity_not_found = None
        self._git = None
        self._googledisk = None
        self._gs = None
        self._hostpath = None
        self._model = None
        self._nfs = None
        self._s3 = None
        self._source_entity_type = None
        self.discriminator = None

        if artifact is not None:
            self.artifact = artifact
        if cifs is not None:
            self.cifs = cifs
        if csi is not None:
            self.csi = csi
        if dataset is not None:
            self.dataset = dataset
        if entity_not_found is not None:
            self.entity_not_found = entity_not_found
        if git is not None:
            self.git = git
        if googledisk is not None:
            self.googledisk = googledisk
        if gs is not None:
            self.gs = gs
        if hostpath is not None:
            self.hostpath = hostpath
        if model is not None:
            self.model = model
        if nfs is not None:
            self.nfs = nfs
        if s3 is not None:
            self.s3 = s3
        if source_entity_type is not None:
            self.source_entity_type = source_entity_type

    @property
    def artifact(self):
        """Gets the artifact of this ResponseVolumeSourceEntity.  # noqa: E501


        :return: The artifact of this ResponseVolumeSourceEntity.  # noqa: E501
        :rtype: ResponseArtifact
        """
        return self._artifact

    @artifact.setter
    def artifact(self, artifact):
        """Sets the artifact of this ResponseVolumeSourceEntity.


        :param artifact: The artifact of this ResponseVolumeSourceEntity.  # noqa: E501
        :type artifact: ResponseArtifact
        """

        self._artifact = artifact

    @property
    def cifs(self):
        """Gets the cifs of this ResponseVolumeSourceEntity.  # noqa: E501


        :return: The cifs of this ResponseVolumeSourceEntity.  # noqa: E501
        :rtype: V1CIFSMount
        """
        return self._cifs

    @cifs.setter
    def cifs(self, cifs):
        """Sets the cifs of this ResponseVolumeSourceEntity.


        :param cifs: The cifs of this ResponseVolumeSourceEntity.  # noqa: E501
        :type cifs: V1CIFSMount
        """

        self._cifs = cifs

    @property
    def csi(self):
        """Gets the csi of this ResponseVolumeSourceEntity.  # noqa: E501


        :return: The csi of this ResponseVolumeSourceEntity.  # noqa: E501
        :rtype: V1CSIMount
        """
        return self._csi

    @csi.setter
    def csi(self, csi):
        """Sets the csi of this ResponseVolumeSourceEntity.


        :param csi: The csi of this ResponseVolumeSourceEntity.  # noqa: E501
        :type csi: V1CSIMount
        """

        self._csi = csi

    @property
    def dataset(self):
        """Gets the dataset of this ResponseVolumeSourceEntity.  # noqa: E501


        :return: The dataset of this ResponseVolumeSourceEntity.  # noqa: E501
        :rtype: ResponseDatasetInfo
        """
        return self._dataset

    @dataset.setter
    def dataset(self, dataset):
        """Sets the dataset of this ResponseVolumeSourceEntity.


        :param dataset: The dataset of this ResponseVolumeSourceEntity.  # noqa: E501
        :type dataset: ResponseDatasetInfo
        """

        self._dataset = dataset

    @property
    def entity_not_found(self):
        """Gets the entity_not_found of this ResponseVolumeSourceEntity.  # noqa: E501


        :return: The entity_not_found of this ResponseVolumeSourceEntity.  # noqa: E501
        :rtype: bool
        """
        return self._entity_not_found

    @entity_not_found.setter
    def entity_not_found(self, entity_not_found):
        """Sets the entity_not_found of this ResponseVolumeSourceEntity.


        :param entity_not_found: The entity_not_found of this ResponseVolumeSourceEntity.  # noqa: E501
        :type entity_not_found: bool
        """

        self._entity_not_found = entity_not_found

    @property
    def git(self):
        """Gets the git of this ResponseVolumeSourceEntity.  # noqa: E501


        :return: The git of this ResponseVolumeSourceEntity.  # noqa: E501
        :rtype: V1GitReference
        """
        return self._git

    @git.setter
    def git(self, git):
        """Sets the git of this ResponseVolumeSourceEntity.


        :param git: The git of this ResponseVolumeSourceEntity.  # noqa: E501
        :type git: V1GitReference
        """

        self._git = git

    @property
    def googledisk(self):
        """Gets the googledisk of this ResponseVolumeSourceEntity.  # noqa: E501


        :return: The googledisk of this ResponseVolumeSourceEntity.  # noqa: E501
        :rtype: V1GoogleDiskMount
        """
        return self._googledisk

    @googledisk.setter
    def googledisk(self, googledisk):
        """Sets the googledisk of this ResponseVolumeSourceEntity.


        :param googledisk: The googledisk of this ResponseVolumeSourceEntity.  # noqa: E501
        :type googledisk: V1GoogleDiskMount
        """

        self._googledisk = googledisk

    @property
    def gs(self):
        """Gets the gs of this ResponseVolumeSourceEntity.  # noqa: E501


        :return: The gs of this ResponseVolumeSourceEntity.  # noqa: E501
        :rtype: V1GSReference
        """
        return self._gs

    @gs.setter
    def gs(self, gs):
        """Sets the gs of this ResponseVolumeSourceEntity.


        :param gs: The gs of this ResponseVolumeSourceEntity.  # noqa: E501
        :type gs: V1GSReference
        """

        self._gs = gs

    @property
    def hostpath(self):
        """Gets the hostpath of this ResponseVolumeSourceEntity.  # noqa: E501


        :return: The hostpath of this ResponseVolumeSourceEntity.  # noqa: E501
        :rtype: V1HostPathMount
        """
        return self._hostpath

    @hostpath.setter
    def hostpath(self, hostpath):
        """Sets the hostpath of this ResponseVolumeSourceEntity.


        :param hostpath: The hostpath of this ResponseVolumeSourceEntity.  # noqa: E501
        :type hostpath: V1HostPathMount
        """

        self._hostpath = hostpath

    @property
    def model(self):
        """Gets the model of this ResponseVolumeSourceEntity.  # noqa: E501


        :return: The model of this ResponseVolumeSourceEntity.  # noqa: E501
        :rtype: ResponseModelCandidateInfo
        """
        return self._model

    @model.setter
    def model(self, model):
        """Sets the model of this ResponseVolumeSourceEntity.


        :param model: The model of this ResponseVolumeSourceEntity.  # noqa: E501
        :type model: ResponseModelCandidateInfo
        """

        self._model = model

    @property
    def nfs(self):
        """Gets the nfs of this ResponseVolumeSourceEntity.  # noqa: E501


        :return: The nfs of this ResponseVolumeSourceEntity.  # noqa: E501
        :rtype: V1NFSMount
        """
        return self._nfs

    @nfs.setter
    def nfs(self, nfs):
        """Sets the nfs of this ResponseVolumeSourceEntity.


        :param nfs: The nfs of this ResponseVolumeSourceEntity.  # noqa: E501
        :type nfs: V1NFSMount
        """

        self._nfs = nfs

    @property
    def s3(self):
        """Gets the s3 of this ResponseVolumeSourceEntity.  # noqa: E501


        :return: The s3 of this ResponseVolumeSourceEntity.  # noqa: E501
        :rtype: V1S3Reference
        """
        return self._s3

    @s3.setter
    def s3(self, s3):
        """Sets the s3 of this ResponseVolumeSourceEntity.


        :param s3: The s3 of this ResponseVolumeSourceEntity.  # noqa: E501
        :type s3: V1S3Reference
        """

        self._s3 = s3

    @property
    def source_entity_type(self):
        """Gets the source_entity_type of this ResponseVolumeSourceEntity.  # noqa: E501


        :return: The source_entity_type of this ResponseVolumeSourceEntity.  # noqa: E501
        :rtype: str
        """
        return self._source_entity_type

    @source_entity_type.setter
    def source_entity_type(self, source_entity_type):
        """Sets the source_entity_type of this ResponseVolumeSourceEntity.


        :param source_entity_type: The source_entity_type of this ResponseVolumeSourceEntity.  # noqa: E501
        :type source_entity_type: str
        """
        allowed_values = ["dataset", "model", "artifact", "git", "s3", "gs", "hostpath", "nfs", "cifs", "googledisk", "csi", "unknown"]  # noqa: E501
        if self.local_vars_configuration.client_side_validation and source_entity_type not in allowed_values:  # noqa: E501
            raise ValueError(
                "Invalid value for `source_entity_type` ({0}), must be one of {1}"  # noqa: E501
                .format(source_entity_type, allowed_values)
            )

        self._source_entity_type = source_entity_type

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, ResponseVolumeSourceEntity):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, ResponseVolumeSourceEntity):
            return True

        return self.to_dict() != other.to_dict()



# coding: utf-8

"""
    Aron API

    No description provided (generated by Openapi Generator https://github.com/openapitools/openapi-generator)  # noqa: E501

    The version of the OpenAPI document: 1.0.0
    Generated by: https://openapi-generator.tech
"""


try:
    from inspect import getfullargspec
except ImportError:
    from inspect import getargspec as getfullargspec
import pprint
import re  # noqa: F401
import six

from openapi_client.configuration import Configuration


class LLMDocumentUpdateAPIInput(object):
    """NOTE: This class is auto generated by OpenAPI Generator.
    Ref: https://openapi-generator.tech

    Do not edit the class manually.
    """

    """
    Attributes:
      openapi_types (dict): The key is attribute name
                            and the value is attribute type.
      attribute_map (dict): The key is attribute name
                            and the value is json key in definition.
    """
    openapi_types = {
        'chunking_method_params': 'dict[str, object]',
        'chunking_method_type': 'str',
        'download_url': 'str',
        'extension': 'str',
        'filename': 'str',
        'parser_type': 'str',
        'upload_successful': 'bool'
    }

    attribute_map = {
        'chunking_method_params': 'chunking_method_params',
        'chunking_method_type': 'chunking_method_type',
        'download_url': 'download_url',
        'extension': 'extension',
        'filename': 'filename',
        'parser_type': 'parser_type',
        'upload_successful': 'upload_successful'
    }

    def __init__(self, chunking_method_params=None, chunking_method_type=None, download_url=None, extension=None, filename=None, parser_type=None, upload_successful=None, local_vars_configuration=None):  # noqa: E501
        """LLMDocumentUpdateAPIInput - a model defined in OpenAPI"""  # noqa: E501
        if local_vars_configuration is None:
            local_vars_configuration = Configuration.get_default_copy()
        self.local_vars_configuration = local_vars_configuration

        self._chunking_method_params = None
        self._chunking_method_type = None
        self._download_url = None
        self._extension = None
        self._filename = None
        self._parser_type = None
        self._upload_successful = None
        self.discriminator = None

        if chunking_method_params is not None:
            self.chunking_method_params = chunking_method_params
        if chunking_method_type is not None:
            self.chunking_method_type = chunking_method_type
        if download_url is not None:
            self.download_url = download_url
        if extension is not None:
            self.extension = extension
        if filename is not None:
            self.filename = filename
        if parser_type is not None:
            self.parser_type = parser_type
        if upload_successful is not None:
            self.upload_successful = upload_successful

    @property
    def chunking_method_params(self):
        """Gets the chunking_method_params of this LLMDocumentUpdateAPIInput.  # noqa: E501


        :return: The chunking_method_params of this LLMDocumentUpdateAPIInput.  # noqa: E501
        :rtype: dict[str, object]
        """
        return self._chunking_method_params

    @chunking_method_params.setter
    def chunking_method_params(self, chunking_method_params):
        """Sets the chunking_method_params of this LLMDocumentUpdateAPIInput.


        :param chunking_method_params: The chunking_method_params of this LLMDocumentUpdateAPIInput.  # noqa: E501
        :type chunking_method_params: dict[str, object]
        """

        self._chunking_method_params = chunking_method_params

    @property
    def chunking_method_type(self):
        """Gets the chunking_method_type of this LLMDocumentUpdateAPIInput.  # noqa: E501


        :return: The chunking_method_type of this LLMDocumentUpdateAPIInput.  # noqa: E501
        :rtype: str
        """
        return self._chunking_method_type

    @chunking_method_type.setter
    def chunking_method_type(self, chunking_method_type):
        """Sets the chunking_method_type of this LLMDocumentUpdateAPIInput.


        :param chunking_method_type: The chunking_method_type of this LLMDocumentUpdateAPIInput.  # noqa: E501
        :type chunking_method_type: str
        """

        self._chunking_method_type = chunking_method_type

    @property
    def download_url(self):
        """Gets the download_url of this LLMDocumentUpdateAPIInput.  # noqa: E501


        :return: The download_url of this LLMDocumentUpdateAPIInput.  # noqa: E501
        :rtype: str
        """
        return self._download_url

    @download_url.setter
    def download_url(self, download_url):
        """Sets the download_url of this LLMDocumentUpdateAPIInput.


        :param download_url: The download_url of this LLMDocumentUpdateAPIInput.  # noqa: E501
        :type download_url: str
        """

        self._download_url = download_url

    @property
    def extension(self):
        """Gets the extension of this LLMDocumentUpdateAPIInput.  # noqa: E501


        :return: The extension of this LLMDocumentUpdateAPIInput.  # noqa: E501
        :rtype: str
        """
        return self._extension

    @extension.setter
    def extension(self, extension):
        """Sets the extension of this LLMDocumentUpdateAPIInput.


        :param extension: The extension of this LLMDocumentUpdateAPIInput.  # noqa: E501
        :type extension: str
        """

        self._extension = extension

    @property
    def filename(self):
        """Gets the filename of this LLMDocumentUpdateAPIInput.  # noqa: E501


        :return: The filename of this LLMDocumentUpdateAPIInput.  # noqa: E501
        :rtype: str
        """
        return self._filename

    @filename.setter
    def filename(self, filename):
        """Sets the filename of this LLMDocumentUpdateAPIInput.


        :param filename: The filename of this LLMDocumentUpdateAPIInput.  # noqa: E501
        :type filename: str
        """

        self._filename = filename

    @property
    def parser_type(self):
        """Gets the parser_type of this LLMDocumentUpdateAPIInput.  # noqa: E501


        :return: The parser_type of this LLMDocumentUpdateAPIInput.  # noqa: E501
        :rtype: str
        """
        return self._parser_type

    @parser_type.setter
    def parser_type(self, parser_type):
        """Sets the parser_type of this LLMDocumentUpdateAPIInput.


        :param parser_type: The parser_type of this LLMDocumentUpdateAPIInput.  # noqa: E501
        :type parser_type: str
        """

        self._parser_type = parser_type

    @property
    def upload_successful(self):
        """Gets the upload_successful of this LLMDocumentUpdateAPIInput.  # noqa: E501


        :return: The upload_successful of this LLMDocumentUpdateAPIInput.  # noqa: E501
        :rtype: bool
        """
        return self._upload_successful

    @upload_successful.setter
    def upload_successful(self, upload_successful):
        """Sets the upload_successful of this LLMDocumentUpdateAPIInput.


        :param upload_successful: The upload_successful of this LLMDocumentUpdateAPIInput.  # noqa: E501
        :type upload_successful: bool
        """

        self._upload_successful = upload_successful

    def to_dict(self, serialize=False):
        """Returns the model properties as a dict"""
        result = {}

        def convert(x):
            if hasattr(x, "to_dict"):
                args = getfullargspec(x.to_dict).args
                if len(args) == 1:
                    return x.to_dict()
                else:
                    return x.to_dict(serialize)
            else:
                return x

        for attr, _ in six.iteritems(self.openapi_types):
            value = getattr(self, attr)
            attr = self.attribute_map.get(attr, attr) if serialize else attr
            if isinstance(value, list):
                result[attr] = list(map(
                    lambda x: convert(x),
                    value
                ))
            elif isinstance(value, dict):
                result[attr] = dict(map(
                    lambda item: (item[0], convert(item[1])),
                    value.items()
                ))
            else:
                result[attr] = convert(value)

        return result

    def to_str(self):
        """Returns the string representation of the model"""
        return pprint.pformat(self.to_dict())

    def __repr__(self):
        """For `print` and `pprint`"""
        return self.to_str()

    def __eq__(self, other):
        """Returns true if both objects are equal"""
        if not isinstance(other, LLMDocumentUpdateAPIInput):
            return False

        return self.to_dict() == other.to_dict()

    def __ne__(self, other):
        """Returns true if both objects are not equal"""
        if not isinstance(other, LLMDocumentUpdateAPIInput):
            return True

        return self.to_dict() != other.to_dict()
